@@ -39,7 +39,8 @@ test_that("eive.cga classical example", {
     expect_equal(as.vector(par_eive), c(23.863, 9.229), tolerance = tol)
     expect_equal(as.vector(par_ols), c(63.590, 5.533), tolerance = tol)
 
-    for (i in 1:length(result$measurementerror)){
+    L <- length(result$measurementerror)
+    for (i in 1:L){
         expect_equal(result$proxy$residuals[i], result$measurementerror[i])
     }
 
@@ -50,3 +51,4 @@ test_that("eive.cga classical example", {
     expect_true("cleanedx" %in% result_names)
     expect_true("measurementerror" %in% result_names)
 })
+
